"""Main entry point for lace command."""

from lace.cli import main

if __name__ == "__main__":
    main()
